pyLBM.elements.Cylinder_Triangle
================================

.. currentmodule:: pyLBM.elements

.. autoclass:: Cylinder_Triangle

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Cylinder_Triangle.change_of_variables
         Cylinder_Triangle.distance
         Cylinder_Triangle.get_bounds
         Cylinder_Triangle.point_inside
         Cylinder_Triangle.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Cylinder_Triangle.number_of_bounds

